Skip site navigation (1)Skip section navigation (2)
Date:      Mon, 10 Aug 1998 19:50:07 +0200 (CEST)
From:      Christian Weisgerber <naddy@bigeye.rhein-neckar.de>
To:        FreeBSD-gnats-submit@FreeBSD.ORG
Subject:   kern/7559: pcvt treats DEL as a printable character
Message-ID:  <199808101750.TAA02863@bigeye.rhein-neckar.de>

next in thread | raw e-mail | index | archive | help

>Number:         7559
>Category:       kern
>Synopsis:       pcvt treats DEL as a printable character
>Confidential:   no
>Severity:       non-critical
>Priority:       medium
>Responsible:    freebsd-bugs
>State:          open
>Quarter:
>Keywords:
>Date-Required:
>Class:          sw-bug
>Submitter-Id:   current-users
>Arrival-Date:   Mon Aug 10 11:40:00 PDT 1998
>Last-Modified:
>Originator:     Christian Weisgerber
>Organization:
>Release:        FreeBSD 2.2.7-STABLE i386
>Environment:

pcvt VT220-compatible console driver.

>Description:

The pcvt console driver outputs a glyph for the ASCII DEL (0x7F)
character. This differs from the behavior of an actual DEC VT220
terminal which treats DEL as a non-printable no-op control character.

>How-To-Repeat:


>Fix:
	
--- /sys/i386/isa/pcvt/pcvt_out.c.orig	Fri Mar  7 09:58:26 1997
+++ /sys/i386/isa/pcvt/pcvt_out.c	Mon Aug 10 16:12:49 1998
@@ -178,10 +178,10 @@
 	if(svsp->sevenbit)
 		ch &= 0x7f;
 
-	if((ch <= 0x1f) && (svsp->transparent == 0))
+	if(((ch <= 0x1f) || (ch == 0x7f)) && (svsp->transparent == 0))
 	{
 
 	/* always process control-chars in the range 0x00..0x1f !!! */
 
 		if(svsp->dis_fnc)
 		{
@@ -323,6 +323,7 @@
 				case 0x1d:	/* GS */
 				case 0x1e:	/* RS */
 				case 0x1f:	/* US */
+				case 0x7f:	/* DEL */
 				break;
 			}
 		}
@@ -330,7 +331,8 @@
 	else
 	{
 
-	/* char range 0x20...0xff processing depends on current state */
+	/* char range 0x20...0x7e, 0x80...0xff processing */
+	/* depends on current state */
 
 		switch(svsp->state)
 		{
@@ -1884,7 +1886,7 @@
  *	partial HP 2392 ANSI mode Emulator
  *	==================================
  *
- *	this part tooks over the emulation of some escape sequences
+ *	this part takes over the emulation of some escape sequences
  *	needed to handle the function key labels
  *
  *	They are modeled after the corresponding escape sequences
@@ -178,10 +178,10 @@
 	{
 
-	/* always process control-chars in the range 0x00..0x1f !!! */
+	/* always process control-chars in the range 0x00..0x1f, 0x7f !!! */
 
 		if(svsp->dis_fnc)
>Audit-Trail:
>Unformatted:

To Unsubscribe: send mail to majordomo@FreeBSD.org
with "unsubscribe freebsd-bugs" in the body of the message



Want to link to this message? Use this URL: <https://mail-archive.FreeBSD.org/cgi/mid.cgi?199808101750.TAA02863>